@@ -273,19 +273,36 @@ border_css <- function(x, side) {
 
 # ppr ----
 ppr_pml <- function(x) {
-  align <- " algn=\"r\""
-  if (x$text.align == "left") {
-    align <- " algn=\"l\""
-  } else if (x$text.align == "center") {
-    align <- " algn=\"ctr\""
-  } else if (x$text.align == "justify") {
-    align <- " algn=\"just\""
-  }
-  leftright_padding <- sprintf(" marL=\"%.0f\" marR=\"%.0f\"", x$padding.left * 12700, x$padding.right * 12700)
-  top_padding <- sprintf("<a:spcBef><a:spcPts val=\"%.0f\" /></a:spcBef>", x$padding.top * 100)
-  bottom_padding <- sprintf("<a:spcAft><a:spcPts val=\"%.0f\" /></a:spcAft>", x$padding.bottom * 100)
 
-  line_spacing <- sprintf("<a:lnSpc><a:spcPct val=\"%.0f\"/></a:lnSpc>", x$line_spacing * 100000)
+  align <- ""
+  if (!is.na(x$text.align)) {
+    align <- " algn=\"r\""
+    if (x$text.align == "left") {
+      align <- " algn=\"l\""
+    } else if (x$text.align == "center") {
+      align <- " algn=\"ctr\""
+    } else if (x$text.align == "justify") {
+      align <- " algn=\"just\""
+    }
+  }
+
+  leftright_padding <- ""
+  if (!is.na(x$padding.left) && !is.na(x$padding.right)) {
+    leftright_padding <- sprintf(" marL=\"%.0f\" marR=\"%.0f\"", x$padding.left * 12700, x$padding.right * 12700)
+  }
+
+  top_padding <- ""
+  if (!is.na(x$padding.top)) {
+    top_padding <- sprintf("<a:spcBef><a:spcPts val=\"%.0f\" /></a:spcBef>", x$padding.top * 100)
+  }
+  bottom_padding <- ""
+  if (!is.na(x$padding.bottom)) {
+    bottom_padding <- sprintf("<a:spcAft><a:spcPts val=\"%.0f\" /></a:spcAft>", x$padding.bottom * 100)
+  }
+  line_spacing <- ""
+  if (!is.na(x$line_spacing)) {
+    line_spacing <- sprintf("<a:lnSpc><a:spcPct val=\"%.0f\"/></a:lnSpc>", x$line_spacing * 100000)
+  }
 
   paste0(
     "<a:pPr", align, leftright_padding, ">",
@@ -324,35 +341,54 @@ ppr_wml <- function(x) {
     x$text.align <- "both"
   }
   pstyle <- ""
-  if (!is.null(x$word_style)) {
-    word_style_id <- gsub("[^a-zA-Z0-9]", "", x$word_style)
-    pstyle <- sprintf("<w:pStyle w:val=\"%s\"/>", word_style_id)
+  if (!is.null(x$word_style) && !is.na(x$word_style)) {
+    pstyle <- sprintf("<w:pStyle w:pstlname=\"%s\"/>", x$word_style)
   }
   tabs <- ""
-  if (!is.null(x$tabs)) {
+  if (!is.null(x$tabs) && !isFALSE(x$tabs)) {
     tabs <- to_wml(x$tabs)
   }
-  text_align_ <- sprintf("<w:jc w:val=\"%s\"/>", x$text.align)
+
+  text_align_ <- ""
+  if (!is.na(x$text.align)) {
+    text_align_ <- sprintf("<w:jc w:val=\"%s\"/>", x$text.align)
+  }
+
   keep_with_next <- ""
-  if (x$keep_with_next) {
+  if (isTRUE(x$keep_with_next)) {
     keep_with_next <- "<w:keepNext/>"
   }
-  borders_ <- paste0(
-    "<w:pBdr>",
-    border_wml(x$border.bottom, "bottom"),
-    border_wml(x$border.top, "top"),
-    border_wml(x$border.left, "left"),
-    border_wml(x$border.right, "right"), "</w:pBdr>"
-  )
 
-  leftright_padding <- sprintf(
-    "<w:ind w:left=\"%.0f\" w:right=\"%.0f\" w:firstLine=\"0\" w:firstLineChars=\"0\"/>",
-    x$padding.left * 20, x$padding.right * 20
-  )
-  topbot_spacing <- sprintf(
-    "<w:spacing w:after=\"%.0f\" w:before=\"%.0f\" w:line=\"%.0f\"/>",
-    x$padding.bottom * 20, x$padding.top * 20, x$line_spacing * 240
-  )
+  borders_ <- ""
+  if (!is.null(x$border.top) && !isFALSE(x$border.top) &&
+      !is.null(x$border.bottom) && !isFALSE(x$border.bottom) &&
+      !is.null(x$border.left) && !isFALSE(x$border.left) &&
+      !is.null(x$border.right) && !isFALSE(x$border.right)) {
+    borders_ <- paste0(
+      "<w:pBdr>",
+      border_wml(x$border.bottom, "bottom"),
+      border_wml(x$border.top, "top"),
+      border_wml(x$border.left, "left"),
+      border_wml(x$border.right, "right"), "</w:pBdr>"
+    )
+  }
+
+  leftright_padding <- ""
+  if (!is.na(x$padding.left) && !is.na(x$padding.right)) {
+    leftright_padding <- sprintf(
+      "<w:ind w:left=\"%.0f\" w:right=\"%.0f\" w:firstLine=\"0\" w:firstLineChars=\"0\"/>",
+      x$padding.left * 20, x$padding.right * 20
+    )
+  }
+
+  topbot_spacing <- ""
+  if (!is.na(x$padding.bottom) && !is.na(x$padding.top) && !is.na(x$line_spacing)) {
+    topbot_spacing <- sprintf(
+      "<w:spacing w:after=\"%.0f\" w:before=\"%.0f\" w:line=\"%.0f\"/>",
+      x$padding.bottom * 20, x$padding.top * 20, x$line_spacing * 240
+    )
+  }
+
   shading_ <- ""
   if (!is_transparent(x$shading.color)) {
     shading_ <- sprintf(
@@ -415,6 +451,13 @@ rpr_pml <- function(x) {
     }
   }
 
+  has_strike <- !is.null(x$strike) && !is.na(x$strike) && x$strike
+  if (has_strike) {
+    out <- paste0(out, " strike=\"sngStrike\"")
+  } else {
+    out <- paste0(out, " strike=\"noStrike\"")
+  }
+
   if (x$vertical.align == "superscript") {
     out <- paste0(out, " baseline=\"40000\"")
   } else if (x$vertical.align == "subscript") {
@@ -484,6 +527,13 @@ rpr_wml <- function(x) {
     }
   }
 
+  has_strike <- !is.null(x$strike) && !is.na(x$strike) && x$strike
+  if (has_strike) {
+    out <- paste0(out, "<w:strike w:val=\"true\"/>")
+  } else {
+    out <- paste0(out, "<w:strike w:val=\"false\"/>")
+  }
+
   if (x$vertical.align == "superscript") {
     out <- paste0(out, "<w:vertAlign w:val=\"superscript\"/>")
   } else if (x$vertical.align == "subscript") {
@@ -560,12 +610,14 @@ rpr_css <- function(x) {
     }
   }
 
-  if (!is.na(x$bold)) {
-    if (x$underlined) {
-      out <- paste0(out, "text-decoration:underline;")
-    } else {
-      out <- paste0(out, "text-decoration:none;")
-    }
+  has_underline <- !is.na(x$underlined) && x$underlined
+  if (has_underline) {
+    out <- paste0(out, "text-decoration:underline;")
+  }
+
+  has_strike <- !is.null(x$strike) && !is.na(x$strike) && x$strike
+  if (has_strike) {
+    out <- paste0(out, "text-decoration:line-through;")
   }
 
   if (!is.na(x$shading.color)) {
