@@ -7,10 +7,12 @@
 #' objects are:
 #' - [ftext()]
 #' - [external_img()]
-#' - [run_word_field()]
-#' - [run_pagebreak()]
+#' - [run_autonum()]
 #' - [run_columnbreak()]
 #' - [run_linebreak()]
+#' - [run_word_field()]
+#' - [run_reference()]
+#' - [run_pagebreak()]
 #' - [hyperlink_ftext()]
 #' - [block_list()]
 #' - [fpar()]
@@ -29,7 +31,7 @@ to_rtf.fpar <- function(x, ...) {
   rtf_chunks <- lapply(chks, to_rtf)
   rtf_chunks$collapse <- ""
   rtf_chunks <- do.call(paste0, rtf_chunks)
-  paste0("{\\pard", ppr_rtf(x$fp_p), rtf_chunks, "\\par}")
+  paste0("{", ppr_rtf(x$fp_p), rtf_chunks, "\\par}")
 }
 
 #' @export
@@ -71,6 +73,12 @@ to_rtf.ftext <- function(x, ...) {
   paste0(rtf_fp_strings, value)
 }
 
+#' @export
+to_rtf.run_tab <- function(x, ...) {
+  "\\tab "
+}
+
+
 #' @export
 to_rtf.external_img <- function(x, ...) {
   dims <- attr(x, "dims")
@@ -96,6 +104,184 @@ to_rtf.external_img <- function(x, ...) {
   paste(rtf_str, dat, "\n}", sep = "")
 }
 
+
+#' @export
+to_rtf.floating_external_img <- function(x, ...) {
+  dims <- attr(x, "dims")
+  width <- dims$width
+  height <- dims$height
+
+  pos <- attr(x, "pos")
+  pos_x <- pos$x
+  pos_y <- pos$y
+  pos_h_from <- pos$h_from
+  pos_v_from <- pos$v_from
+
+  wrap <- attr(x, "wrap")
+  wrap_type <- wrap$type
+  wrap_side <- wrap$side
+  wrap_dist_top <- wrap$dist_top
+  wrap_dist_bottom <- wrap$dist_bottom
+  wrap_dist_left <- wrap$dist_left
+  wrap_dist_right <- wrap$dist_right
+
+  if (!grepl("\\.png$", x)) {
+    imgpath <- tempfile(fileext = ".png")
+    img <- magick::image_read(x)
+    magick::image_write(img, path = imgpath)
+  } else {
+    imgpath <- x
+  }
+
+  # Read image data
+  dat <- readBin(imgpath, what = "raw", size = 1, endian = "little", n = 1e+8)
+  dat <- paste(dat, collapse = "")
+
+  # RTF units: twips (1/1440 inch)
+  width_twips <- width * 1440
+  height_twips <- height * 1440
+  pos_x_twips <- pos_x * 1440
+  pos_y_twips <- pos_y * 1440
+
+  # EMU units for wrap distances (1 EMU = 1/914400 inch, so multiply inches by 914400)
+  # But for RTF {\sp{\sn property}{\sv value}}, wrap distances are in EMUs
+  dist_t_emus <- wrap_dist_top * 914400
+  dist_b_emus <- wrap_dist_bottom * 914400
+  dist_l_emus <- wrap_dist_left * 914400
+  dist_r_emus <- wrap_dist_right * 914400
+
+  # RTF wrap codes for \shpwr:
+  # 1 = wrap around top and bottom
+  # 2 = wrap around shape
+  # 3 = none (as if shape isn't present)
+  # 4 = wrap tightly
+  # 5 = wrap text through shape
+  wrap_code <- switch(wrap_type,
+    "square" = "\\shpwr2",
+    "tight" = "\\shpwr4",
+    "topAndBottom" = "\\shpwr1",
+    "through" = "\\shpwr5",
+    "none" = "\\shpwr3",
+    "\\shpwr2"  # Default to square wrap
+  )
+
+  # RTF wrap side codes for \shpwrk:
+  # 0 = wrap both sides
+  # 1 = wrap left side only
+  # 2 = wrap right side only
+  # 3 = wrap only on largest side
+  wrap_side_code <- switch(wrap_side,
+    "bothSides" = "\\shpwrk0",
+    "left" = "\\shpwrk1",
+    "right" = "\\shpwrk2",
+    "largest" = "\\shpwrk3",
+    "\\shpwrk0"  # Default
+  )
+
+  # RTF positioning codes
+  # Horizontal positioning relative to:
+  # \shpbxpage = page, \shpbxmargin = margin, \shpbxcolumn = column
+  pos_h_code <- switch(pos_h_from,
+    "page" = "\\shpbxpage",
+    "margin" = "\\shpbxmargin",
+    "column" = "\\shpbxcolumn",
+    "character" = "\\shpbxcolumn",
+    "\\shpbxmargin"  # Default
+  )
+
+  # Vertical positioning relative to:
+  # \shpbypage = page, \shpbymargin = margin, \shpbypara = paragraph
+  pos_v_code <- switch(pos_v_from,
+    "page" = "\\shpbypage",
+    "margin" = "\\shpbymargin",
+    "paragraph" = "\\shpbypara",
+    "line" = "\\shpbypara",
+    "\\shpbymargin"  # Default
+  )
+
+  # posrelh property: 0=margin, 1=page, 2=column
+  posrelh <- switch(pos_h_from,
+    "margin" = 0,
+    "page" = 1,
+    "column" = 2,
+    "character" = 2,
+    0  # Default to margin
+  )
+
+  # posrelv property: 0=margin, 1=page, 2=paragraph
+  posrelv <- switch(pos_v_from,
+    "margin" = 0,
+    "page" = 1,
+    "paragraph" = 2,
+    "line" = 2,
+    0  # Default to margin
+  )
+
+  # Build the RTF shape structure following Word's format:
+  # {\shp \shpleft... \shptop... \shpright... \shpbottom... \shpfhdr0
+  #       \shpbx... \shpbxignore \shpby... \shpbyignore
+  #       \shpwr... \shpwrk... \shpfblwtxt... \shpz... \shplid...
+  #       {\*\shpinst {\sp{\sn prop}{\sv val}}... \par}}}
+
+  rtf_str <- paste0(
+    "{\\shp",
+    sprintf("\\shpleft%.0f\\shptop%.0f\\shpright%.0f\\shpbottom%.0f",
+            pos_x_twips, pos_y_twips,
+            pos_x_twips + width_twips, pos_y_twips + height_twips),
+    "\\shpfhdr0",  # Not in header/footer
+    pos_h_code, "\\shpbxignore",  # Horizontal positioning
+    pos_v_code, "\\shpbyignore",  # Vertical positioning
+    wrap_code, wrap_side_code,  # Wrap type and side
+    "\\shpfblwtxt0",  # Image in front of text
+    "\\shpz0",  # Z-order
+    "\\shplid1027"  # Shape ID
+  )
+
+  # Start the shape properties ({\*\shpinst ...})
+  rtf_str <- paste0(rtf_str, "{\\*\\shpinst")
+
+  # Add shape properties following {\sp{\sn PropertyName}{\sv PropertyValue}} format
+  # shapeType: 75 = picture frame
+  rtf_str <- paste0(rtf_str, "{\\sp{\\sn shapeType}{\\sv 75}}")
+
+  # pib: Binary picture data
+  rtf_str <- paste0(
+    rtf_str,
+    sprintf(
+      "{\\sp{\\sn pib}{\\sv {\\pict\\pngblip\\picwgoal%.0f\\pichgoal%.0f %s}}}",
+      width_twips, height_twips, dat
+    )
+  )
+
+  # Add wrap distances (in EMUs)
+  if (dist_l_emus > 0) {
+    rtf_str <- paste0(rtf_str, sprintf("{\\sp{\\sn dxWrapDistLeft}{\\sv %.0f}}", dist_l_emus))
+  }
+  if (dist_r_emus > 0) {
+    rtf_str <- paste0(rtf_str, sprintf("{\\sp{\\sn dxWrapDistRight}{\\sv %.0f}}", dist_r_emus))
+  }
+  if (dist_t_emus > 0) {
+    rtf_str <- paste0(rtf_str, sprintf("{\\sp{\\sn dyWrapDistTop}{\\sv %.0f}}", dist_t_emus))
+  }
+  if (dist_b_emus > 0) {
+    rtf_str <- paste0(rtf_str, sprintf("{\\sp{\\sn dyWrapDistBottom}{\\sv %.0f}}", dist_b_emus))
+  }
+
+  # Add positioning properties (posrelh, posrelv are not in the Word example,
+  # but keeping them won't hurt for compatibility with newer readers)
+  # Note: These are commented out since the Word example doesn't include them
+  # rtf_str <- paste0(rtf_str, sprintf("{\\sp{\\sn posrelh}{\\sv %d}}", posrelh))
+  # rtf_str <- paste0(rtf_str, sprintf("{\\sp{\\sn posrelv}{\\sv %d}}", posrelv))
+
+  # fBehindDocument: 0 = in front of text, 1 = behind text
+  # Note: This is redundant with \shpfblwtxt0 above, but Word includes it
+  # rtf_str <- paste0(rtf_str, "{\\sp{\\sn fBehindDocument}{\\sv 0}}")
+
+  # Close the shape structure: \par}}} closes {\*\shpinst and {\shp
+  paste0(rtf_str, "\\par}}}")
+}
+
+
 #' @export
 to_rtf.run_word_field <- function(x, ...) {
   rtf_fp <- ""
@@ -139,20 +325,22 @@ rtf_bookmark <- function(id, str) {
 
 #' @export
 to_rtf.run_autonum <- function(x, ...) {
-  if(is.null(x$seq_id)) return("")
+  if (is.null(x$seq_id)) {
+    return("")
+  }
 
   run_str_pre <- to_rtf(ftext(x$pre_label, prop = x$pr))
   run_str_post <- to_rtf(ftext(x$post_label, prop = x$pr))
 
   seq_str <- paste0("SEQ ", x$seq_id, " \\\\* Arabic")
-  if(!is.null(x$start_at) && is.numeric(x$start_at)){
+  if (!is.null(x$start_at) && is.numeric(x$start_at)) {
     seq_str <- paste(seq_str, "\\r", as.integer(x$start_at))
   }
 
   sqf <- run_word_field(field = seq_str, prop = x$pr)
   sf_str <- to_rtf(sqf)
 
-  if(x$tnd > 0){
+  if (x$tnd > 0) {
     z <- paste0(
       to_rtf(run_word_field(field = paste0("STYLEREF ", x$tnd, " \\r"), prop = x$pr)),
       to_rtf(ftext(x$tns, prop = x$pr))
@@ -160,11 +348,12 @@ to_rtf.run_autonum <- function(x, ...) {
     sf_str <- paste0(z, sf_str)
   }
 
-  if(!is.null(x$bookmark)){
-    if(x$bookmark_all){
+  if (!is.null(x$bookmark)) {
+    if (x$bookmark_all) {
       out <- paste0(
         rtf_bookmark(id = x$bookmark, str = paste0(run_str_pre, sf_str)),
-        run_str_post)
+        run_str_post
+      )
     } else {
       sf_str <- rtf_bookmark(id = x$bookmark, sf_str)
       out <- paste0(run_str_pre, sf_str, run_str_post)
@@ -205,40 +394,62 @@ to_rtf.prop_section <- function(x, ...) {
 
   hfr_type <- guess_hfr_type(x)
   extra_rtf <- ""
+  str_h <- ""
+  str_f <- ""
+  str_h_even <- ""
+  str_f_even <- ""
+  str_h_first <- ""
+  str_f_first <- ""
+
   if ("none" %in% hfr_type) {
     hfr_str <- ""
   } else if ("default" %in% hfr_type) {
-    hfr_str <- paste0(
-      if (!is.null(x$header_default)) "{\\header ", to_rtf(x$header_default), "}",
-      if (!is.null(x$footer_default)) "{\\footer ", to_rtf(x$footer_default), "}",
-      ""
-    )
+    if (!is.null(x$header_default)) {
+      str_h <- paste0("{\\header ", to_rtf(x$header_default), "}")
+    }
+    if (!is.null(x$footer_default)) {
+      str_f <- paste0("{\\footer ", to_rtf(x$footer_default), "}")
+    }
+    hfr_str <- paste0(str_h, str_f)
   } else if ("evenodd" %in% hfr_type) {
     extra_rtf <- "\\facingp"
+    if (!is.null(x$header_default)) str_h <- paste0("{\\headerl ", to_rtf(x$header_default), "}")
+    if (!is.null(x$header_even)) str_h_even <- paste0("{\\headerr ", to_rtf(x$header_even), "}")
+    if (!is.null(x$footer_default)) str_f <- paste0("{\\footerl ", to_rtf(x$footer_default), "}")
+    if (!is.null(x$footer_even)) str_f_even <- paste0("{\\footerr ", to_rtf(x$footer_even), "}")
     hfr_str <- paste0(
-      if (!is.null(x$header_default)) "{\\headerl ", to_rtf(x$header_default), "}",
-      if (!is.null(x$header_even)) "{\\headerr ", to_rtf(x$header_even), "}",
-      if (!is.null(x$footer_default)) "{\\footerl ", to_rtf(x$footer_default), "}",
-      if (!is.null(x$footer_even)) "{\\footerr ", to_rtf(x$footer_even), "}",
+      str_h,
+      str_h_even,
+      str_f,
+      str_f_even
     )
   } else if ("evenoddfirst" %in% hfr_type) {
     extra_rtf <- "\\facingp\\titlepg"
+    if (!is.null(x$header_default)) str_h <- paste0("{\\headerl ", to_rtf(x$header_default), "}")
+    if (!is.null(x$header_even)) str_h_even <- paste0("{\\headerr ", to_rtf(x$header_even), "}")
+    if (!is.null(x$header_first)) str_h_first <- paste0("{\\headerf ", to_rtf(x$header_first), "}")
+    if (!is.null(x$footer_default)) str_f <- paste0("{\\footerl ", to_rtf(x$footer_default), "}")
+    if (!is.null(x$footer_even)) str_f_even <- paste0("{\\footerr ", to_rtf(x$footer_even), "}")
+    if (!is.null(x$footer_first)) str_f_first <- paste0("{\\footerf ", to_rtf(x$footer_first), "}")
     hfr_str <- paste0(
-      if (!is.null(x$header_default)) "{\\headerl ", to_rtf(x$header_default), "}",
-      if (!is.null(x$header_even)) "{\\headerr ", to_rtf(x$header_even), "}",
-      if (!is.null(x$header_first)) "{\\headerf ", to_rtf(x$header_first), "}",
-      if (!is.null(x$footer_default)) "{\\footerl ", to_rtf(x$footer_default), "}",
-      if (!is.null(x$footer_even)) "{\\footerr ", to_rtf(x$footer_even), "}",
-      if (!is.null(x$footer_first)) "{\\footerf ", to_rtf(x$footer_first), "}",
-      ""
+      str_h,
+      str_h_even,
+      str_h_first,
+      str_f,
+      str_f_even,
+      str_f_first
     )
   } else {
     extra_rtf <- "\\titlepg"
+    if (!is.null(x$header_default)) str_h <- paste0("{\\headerl ", to_rtf(x$header_default), "}")
+    if (!is.null(x$header_first)) str_h_first <- paste0("{\\headerf ", to_rtf(x$header_first), "}")
+    if (!is.null(x$footer_default)) str_f <- paste0("{\\footerl ", to_rtf(x$footer_default), "}")
+    if (!is.null(x$footer_first)) str_f_first <- paste0("{\\footerf ", to_rtf(x$footer_first), "}")
     hfr_str <- paste0(
-      if (!is.null(x$header_default)) "{\\header ", to_rtf(x$header_default), "}",
-      if (!is.null(x$header_first)) "{\\headerf ", to_rtf(x$header_first), "}",
-      if (!is.null(x$footer_default)) "{\\footer ", to_rtf(x$footer_default), "}",
-      if (!is.null(x$footer_first)) "{\\footerf ", to_rtf(x$footer_first), "}"
+      str_h,
+      str_h_first,
+      str_f,
+      str_f_first
     )
   }
 
@@ -290,16 +501,27 @@ to_rtf.page_mar <- function(x, ...) {
 
 #' @export
 to_rtf.page_size <- function(x, ...) {
-  out <- sprintf(
-    "\\pghsxn%.0f\\pgwsxn%.0f%s",
-    inch_to_tweep(x$height),
-    inch_to_tweep(x$width),
-    if ("landscape" %in% x$orient) {
+
+  if (!is.null(x$width) && !is.null(x$height)) {
+    out <- sprintf(
+      "\\pghsxn%.0f\\pgwsxn%.0f%s",
+      inch_to_tweep(x$height),
+      inch_to_tweep(x$width),
+      if ("landscape" %in% x$orient) {
+        "\\lndscpsxn"
+      } else {
+        ""
+      }
+    )
+  } else {
+    out <- if ("landscape" %in% x$orient) {
       "\\lndscpsxn"
     } else {
       ""
     }
-  )
+  }
+
+
   out
 }
 
@@ -344,17 +566,25 @@ color_table <- function(colors) {
 
 ppr_rtf <- function(x) {
   text_align_ <- ""
-  if ("left" %in% x$text.align) {
-    text_align_ <- "\\ql"
-  } else if ("center" %in% x$text.align) {
-    text_align_ <- "\\qc"
-  } else if ("right" %in% x$text.align) {
-    text_align_ <- "\\qr"
-  } else if ("justified" %in% x$text.align) {
-    text_align_ <- "\\qj"
+  if (!is.na(x$text.align)) {
+    if ("left" %in% x$text.align) {
+      text_align_ <- "\\ql"
+    } else if ("center" %in% x$text.align) {
+      text_align_ <- "\\qc"
+    } else if ("right" %in% x$text.align) {
+      text_align_ <- "\\qr"
+    } else if ("justified" %in% x$text.align) {
+      text_align_ <- "\\qj"
+    }
   }
+
+  tabs <- ""
+  if (!is.null(x$tabs) && length(x$tabs) > 0 && !isFALSE(x$tabs)) {
+    tabs <- paste0(sapply(x$tabs, rtf_fp_tab), collapse = "")
+  }
+
   keep_with_next <- ""
-  if (x$keep_with_next) {
+  if (isTRUE(x$keep_with_next)) {
     keep_with_next <- "\\keepn"
   }
   leftright_padding <- ""
@@ -371,15 +601,22 @@ ppr_rtf <- function(x) {
       x$padding.bottom * 20, x$padding.top * 20
     )
   }
+
+  line_spacing <- ""
+  if (!is.na(x$line_spacing)) {
+    line_spacing <- sprintf("\\sl%.0f\\slmult1", 240 * x$line_spacing)
+  }
+
   out <- paste0(
-    sprintf("\\sl%.0f\\slmult1", 240 * x$line_spacing),
+    line_spacing,
     text_align_,
+    tabs,
     keep_with_next,
     topbot_spacing,
     leftright_padding
   )
   if (nchar(out) > 0) {
-    out <- paste0(out, " ")
+    out <- paste0("\\pard", out, " ")
   }
   out
 }
@@ -408,11 +645,16 @@ rpr_rtf <- function(x) {
       out <- paste0(out, "\\ul")
     }
   }
+  if (!is.na(x$strike)) {
+    if (x$strike) {
+      out <- paste0(out, "\\strike")
+    }
+  }
 
-  if (x$vertical.align == "superscript") {
-    out <- paste0(out, "\\super\\up", round(x$font.size / 2))
-  } else if (x$vertical.align == "subscript") {
-    out <- paste0(out, "\\sub\\dn", round(x$font.size / 2))
+  if (x$vertical.align == "superscript" && !is.na(x$font.size)) {
+    out <- paste0(out, sprintf("\\super\\up%.0f", round(x$font.size / 2)))
+  } else if (x$vertical.align == "subscript" && !is.na(x$font.size)) {
+    out <- paste0(out, sprintf("\\sub\\dn%.0f", round(x$font.size / 2)))
   }
 
   if (!is.na(x$font.size)) {
@@ -728,7 +970,7 @@ rtf_add.plot_instr <- function(x, value, width = 6, height = 5, res = 300, scale
   x
 }
 
-#' @title Write an 'RTF' document to a file
+#' @title Write an 'RTF' File
 #' @description Write the RTF object and its content to a file.
 #' @param x an 'rtf' object created with [rtf_doc()]
 #' @param target path to the RTF file to write
@@ -804,7 +1046,6 @@ print.rtf <- function(x, target = NULL, ...) {
 #' @examples
 #' str_encode_to_rtf("Hello World")
 str_encode_to_rtf <- function(z) {
-
   # https://stackoverflow.com/questions/1368020/how-to-output-unicode-string-to-rtf-using-c
   char_list <- strsplit(z, "")
   int_list <- lapply(z, utf8ToInt)
@@ -854,6 +1095,22 @@ rtf_color_code <- function(color) {
   )
 }
 
+rtf_fp_tab <- function(x) {
+  tab_style <- "\\tqdec"
+  if (x$style %in% "left") {
+    tab_style <- ""
+  } else if (x$style %in% "center") {
+    tab_style <- "\\tqc"
+  } else if (x$style %in% "right") {
+    tab_style <- "\\tqr"
+  }
+
+  sprintf(
+    "\\tx%.0f%s",
+    inch_to_tweep(x$pos), tab_style
+  )
+}
+
 rtfize_color_table <- function(x) {
   z <- vapply(x$color, rtf_color_code, "")
   z <- paste0(z, collapse = "")
@@ -928,6 +1185,7 @@ rtf_par_style <- function(fp_p = fp_par(), fp_t = NULL) {
   paste0(ppr_rtf(fp_p), fp_t_rtf)
 }
 
+# Not used in {officer}
 rtf_set_paragraph_style <- function(x, style_name, fp_p = fp_par(), fp_t = NULL) {
   index <- which(x$styles$style_name %in% style_name)
   style_id <- if (length(index) < 1) {
@@ -974,31 +1232,36 @@ if (!"gregexec" %in% getNamespaceExports("base")) {
   # copied from R source, grep.R
   gregexec <- function(pattern, text, ignore.case = FALSE, perl = FALSE,
                        fixed = FALSE, useBytes = FALSE) {
-    if(is.factor(text) && length(levels(text)) < length(text)) {
-      out <- gregexec(pattern, c(levels(text), NA_character_),
-                      ignore.case, perl, fixed, useBytes)
+    if (is.factor(text) && length(levels(text)) < length(text)) {
+      out <- gregexec(
+        pattern, c(levels(text), NA_character_),
+        ignore.case, perl, fixed, useBytes
+      )
       outna <- out[length(out)]
       out <- out[text]
       out[is.na(text)] <- outna
       return(out)
     }
 
-    dat <- gregexpr(pattern = pattern, text=text, ignore.case = ignore.case,
-                    fixed = fixed, useBytes = useBytes, perl = perl)
-    if(perl && !fixed) {
+    dat <- gregexpr(
+      pattern = pattern, text = text, ignore.case = ignore.case,
+      fixed = fixed, useBytes = useBytes, perl = perl
+    )
+    if (perl && !fixed) {
       ## Perl generates match data, so use that
-      capt.attr <- c('capture.start', 'capture.length', 'capture.names')
+      capt.attr <- c("capture.start", "capture.length", "capture.names")
       process <- function(x) {
-        if(anyNA(x) || any(x < 0)) y <- x
-        else {
+        if (anyNA(x) || any(x < 0)) {
+          y <- x
+        } else {
           ## Interleave matches with captures
           y <- t(cbind(x, attr(x, "capture.start")))
           attributes(y)[names(attributes(x))] <- attributes(x)
           ml <- t(cbind(attr(x, "match.length"), attr(x, "capture.length")))
-          nm <- attr(x, 'capture.names')
+          nm <- attr(x, "capture.names")
           ## Remove empty names that `gregexpr` returns
           dimnames(ml) <- dimnames(y) <-
-            if(any(nzchar(nm))) list(c("", nm), NULL)
+            if (any(nzchar(nm))) list(c("", nm), NULL)
           attr(y, "match.length") <- ml
           y
         }
@@ -1009,21 +1272,23 @@ if (!"gregexec" %in% getNamespaceExports("base")) {
     } else {
       ## For TRE or fixed we must compute the match data ourselves
       m1 <- lapply(regmatches(text, dat),
-                   regexec, pattern = pattern, ignore.case = ignore.case,
-                   perl = perl, fixed = fixed, useBytes = useBytes)
+        regexec,
+        pattern = pattern, ignore.case = ignore.case,
+        perl = perl, fixed = fixed, useBytes = useBytes
+      )
       mlen <- lengths(m1)
       res <- vector("list", length(m1))
       im <- mlen > 0
-      res[!im] <- dat[!im]   # -1, NA
+      res[!im] <- dat[!im] # -1, NA
       res[im] <- Map(
         function(outer, inner) {
           tmp <- do.call(cbind, inner)
           attributes(tmp)[names(attributes(inner))] <- attributes(inner)
-          attr(tmp, 'match.length') <-
-            do.call(cbind, lapply(inner, `attr`, 'match.length'))
+          attr(tmp, "match.length") <-
+            do.call(cbind, lapply(inner, `attr`, "match.length"))
           # useBytes/index.type should be same for all so use outer vals
-          attr(tmp, 'useBytes') <- attr(outer, 'useBytes')
-          attr(tmp, 'index.type') <- attr(outer, 'index.type')
+          attr(tmp, "useBytes") <- attr(outer, "useBytes")
+          attr(tmp, "index.type") <- attr(outer, "index.type")
           tmp + rep(outer - 1L, each = nrow(tmp))
         },
         dat[im],
