@@ -1,6 +1,9 @@
 test_that("check errors", {
   x <- read_pptx()
-  expect_error(move_slide(x, index = 2, to = 1), "presentation contains no slide")
+  expect_error(
+    move_slide(x, index = 2, to = 1),
+    "presentation contains no slide"
+  )
 
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
@@ -12,7 +15,7 @@ test_that("check errors", {
 
   x <- on_slide(x, index = 1)
   sm <- slide_summary(x)
-  expect_equal(sm[1,]$text, "Hello world 1")
+  expect_equal(sm[1, ]$text, "Hello world 1")
 
   expect_error(move_slide(x, to = 4))
   expect_error(move_slide(x, index = 5, to = 4))
@@ -29,4 +32,3 @@ test_that("check errors", {
 
 
 unlink("*.pptx")
-
